searchData={"content_type":"text/markdown","items":[{"doc":"Use Sensirion SHT4X humidity and temperature sensors in Elixir","ref":"SHT4X.html","title":"SHT4X","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"SHT4X.html#child_spec/1","title":"SHT4X.child_spec/1","type":"function"},{"doc":"Fetches the latest sample from the sensor's GenServer\n\nThis does not cause an on-demand read from the sensor. Check the `:quality`\nfield for a quick assessment of how much to trust the measurement.","ref":"SHT4X.html#get_sample/1","title":"SHT4X.get_sample/1","type":"function"},{"doc":"Return the sensor's serial number","ref":"SHT4X.html#serial_number/1","title":"SHT4X.serial_number/1","type":"function"},{"doc":"Start a new GenServer for interacting with a SHT4X.","ref":"SHT4X.html#start_link/1","title":"SHT4X.start_link/1","type":"function"},{"doc":"Compensation callback function","ref":"SHT4X.html#t:compensation_callback/0","title":"SHT4X.compensation_callback/0","type":"type"},{"doc":"SHT4X GenServer start_link options\n\n* `:name` - a name for the GenServer\n* `:bus_name` - which I2C bus to use (e.g., `\"i2c-1\"`)\n* `:retries` - the number of retries before failing (defaults to 3 retries)\n* `:compensation_callback` - a function that takes in a `SHT4X.Measurement.t()` and returns a potentially modified `SHT4X.Measurement.t()`\n* `:measurement_interval` - how often data will be read from the sensor (defaults to 5_000 ms)\n* `:repeatability` - accuracy of the requested sensor read (`:low`, `:medium`, or `:high`)\n* `:stale_threshold` - number of milliseconds a sample can remain the current sample before it is marked stale\n* Also accepts all other standard `GenServer` start_link options","ref":"SHT4X.html#t:option/0","title":"SHT4X.option/0","type":"type"},{"doc":"","ref":"SHT4X.html#t:options/0","title":"SHT4X.options/0","type":"type"},{"doc":"How \"fresh\" is the sample we fetched from the sensor's GenServer?\n\nIn the event that the sensor fails to report back a measurement during a polling interval, we re-use the last sample.\nIf this continues to happen over a time period that exceeds the `:stale_threshold`, we mark the re-used \"current\" sample as stale.\n\nThe possible values can be:\n- `:fresh` - This is a recent sample. See the `:stale_threshold`.\n- `:stale` - This is an old sample that should be used with caution.\n- `:unusable` - This is a default sample when no measurements are available.\n- `:converging` - This is optionally set by the temperature compensation algorithm to indicate that it was recently restarted without historic state information and needs more time to give accurate values","ref":"SHT4X.html#t:quality/0","title":"SHT4X.quality/0","type":"type"},{"doc":"One sensor measurement","ref":"SHT4X.Measurement.html","title":"SHT4X.Measurement","type":"module"},{"doc":"Interprets one raw temperature/humidity message\n\nThis returns a Measurement struct with the raw register values and their\ninterpreted temperature and humidity.  It does not apply any compensation so\nthis is real temperature and humidity detected.","ref":"SHT4X.Measurement.html#from_raw/1","title":"SHT4X.Measurement.from_raw/1","type":"function"},{"doc":"","ref":"SHT4X.Measurement.html#t:t/0","title":"SHT4X.Measurement.t/0","type":"type"},{"doc":"# SHT4X\n\n[![Hex version](https://img.shields.io/hexpm/v/sht4x.svg 'Hex version')](https://hex.pm/packages/sht4x)\n[![CircleCI](https://dl.circleci.com/status-badge/img/gh/elixir-sensors/sht4x/tree/main.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/elixir-sensors/sht4x/tree/main)\n\nRead temperature and humidity from [Sensirion SHT4x sensors](https://www.sensirion.com/en/environmental-sensors) in Elixir.","ref":"readme.html","title":"SHT4X","type":"extras"},{"doc":"```elixir\niex> {:ok, sht} = SHT4X.start_link(bus_name: \"i2c-1\")\n{:ok, #PID }\n\niex> SHT4X.get_sample(sht)\n%SHT4X.Measurement{\n  timestamp_ms: 498436,\n  raw_reading_humidity: 28080,\n  raw_reading_temperature: 26379,\n  temperature_c: 22.38528060913086,\n  humidity_rh: 57.131805419921875,\n  dew_point_c: 13.492363250293858,\n  quality: :fresh\n}\n```\n\nFor details, see [API reference](https://hexdocs.pm/sht4x/api-reference.html).","ref":"readme.html#usage","title":"Usage - SHT4X","type":"extras"},{"doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.2.1] - 2023-08-30\n\n#","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"* `SHT4X.Measurement`'s types have been updated to ensure `:humidity_rh` and `:temperature_c` are `float()`\n* The hard-coded `:unusable` measurement value has been updated to return floats as expected. \n\n## [0.2.0] - 2023-07-14\n\n#","ref":"changelog.html#bug-fixes","title":"Bug Fixes - Changelog","type":"extras"},{"doc":"* SHT4X regularly polls temperature and humidity at 5 second intervals\n  (configurable). Regular polling is required for temperature compensation\n  algorithms.\n* The `SHT4X.measure/1` function is now `SHT4X.get_sample/1` to reflect that it\n  returns the latest sample rather than polling the sensor. The `SHT4X.Measurement`\n  struct contains a timestamp and quality information to indicate how stale it\n  is. Staleness could be due to communication issues with the sensor or just\n  waiting for the next poll time.\n* The sensor's serial number is not polled on init. This means that I2C failures\n  or retry delays won't delay or fail startup. They likely will affect the\n  regular polling if they don't resolve themselves.\n\n#","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"* `SHT4X.serial_number/1` to get the sensor's unique serial number\n* The sensor is immediately polled for a temperature. Previously the first\n  temperature measurement was delayed until the interval timer expired (default 5\n  seconds).\n\n## [0.1.4] - 2023-02-01\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"* Catch errors from the transport initialization (thanks to @doawoo)\n\n## [0.1.3] - 2022-12-10\n#","ref":"changelog.html#improvements","title":"Improvements - Changelog","type":"extras"},{"doc":"* Correct typespecs\n* Change use Bitwise to import Bitwise per warning\n* Improve docs\n* Allow users to pass in a `:retries` option for the I2C transport (thank you @doawoo)\n* Update dependencies\n\n## [0.1.2] - 2022-02-11\n#","ref":"changelog.html#improvements","title":"Improvements - Changelog","type":"extras"},{"doc":"- Simplified the transport-related code\n- Refactor the top-level module\n\n#","ref":"changelog.html#improvements","title":"Improvements - Changelog","type":"extras"},{"doc":"- `typed_struct`\n- `circuit_i2c`\n\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- `i2c_server`\n- `mox`\n\n## [0.1.1] - 2021-08-27\n#","ref":"changelog.html#removed","title":"Removed - Changelog","type":"extras"},{"doc":"- Derived `dew_point_c` value\n\n## [0.1.0] - 2021-08-23\n#","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Initial release\n\n[0.2.1]: https://github.com/elixir-sensors/sht4x/compare/v0.2.0..v0.2.1\n[0.2.0]: https://github.com/elixir-sensors/sht4x/compare/v0.1.4..v0.2.0\n[0.1.4]: https://github.com/elixir-sensors/sht4x/compare/v0.1.3..v0.1.4\n[0.1.3]: https://github.com/elixir-sensors/sht4x/compare/v0.1.2..v0.1.3\n[0.1.2]: https://github.com/elixir-sensors/sht4x/compare/v0.1.1..v0.1.2\n[0.1.1]: https://github.com/elixir-sensors/sht4x/compare/v0.1.0..v0.1.1\n[0.1.0]: https://github.com/elixir-sensors/sht4x/releases/tag/v0.1.0","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"}]}